#
# spec file for package WALinuxAgent
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           WALinuxAgent
Summary:        The Microsoft Azure Linux Agent
License:        Apache-2.0
Group:          System/Daemons
Version:        2.0.17
Release:        9.1
Url:            https://github.com/Azure/WALinuxAgent
Source0:        https://github.com/Azure/%{name}/archive/%{name}-%{version}.tar.gz
Source1:        99-azure-timeout.rules
Source2:        README.SUSE
BuildRequires:  python-devel
BuildRequires:  python-setuptools

BuildRequires:  dos2unix

%if 0%{?suse_version}
Requires:       python-xml
%endif

%if 0%{?suse_version} > 1140
BuildRequires:  systemd
%endif
%{?systemd_requires}
%if 0%{?suse_version} < 1140
Requires:       insserv
Requires:       sysvinit
%endif

BuildRequires:  udev

Requires:       grep
Requires:       iptables
Requires:       logrotate
Requires:       openssh
Requires:       openssl
Requires:       pwdutils
Requires:       python-pyasn1
Requires:       sudo
Requires:       util-linux

Conflicts:      NetworkManager

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%endif
BuildArch:      noarch

%description
The Microsoft Azure Linux Agent supports the provisioning and running of Linux
VMs in the Microsoft Azure cloud. This package should be installed on Linux disk
images that are built to run in the Microsoft Azure environment.

%prep
%setup -qn %{name}-%{name}-%{version}

find . -type f -exec sed -i 's/\r//' {} +
find . -type f -exec chmod 0644 {} +

mv README README.old
iconv -f cp1250 -t utf-8 README.old > README
dos2unix README
rm README.old

cp %{SOURCE2} .

%build
python setup.py build

%install
%if 0%{?suse_version} > 1140
python setup.py install --prefix=%{_prefix} --lnx-distro='suse' --init-system='systemd' --root=%{buildroot}
%if 0%{?suse_version} < 1230
    mkdir -p %{buildroot}/%{_unitdir}
    mv %{buildroot}/usr/lib/systemd/system/* %{buildroot}/%{_unitdir}
    rm -rf %{buildroot}/usr/lib/systemd
%endif
%else
python setup.py install --prefix=%{_prefix} --lnx-distro='suse' --init-system='sysV' --root=%{buildroot}
### rc symlink
ln -s ../..%{_initddir}/waagent %{buildroot}%{_sbindir}/rcwaagent
%endif
### udev rules
%if 0%{?suse_version} < 1230
mkdir -p %{buildroot}/lib/udev/rules.d
install -D -m 0644 %{SOURCE1} %{buildroot}/lib/udev/rules.d/99-azure-timeout.rules
mv %{buildroot}/%{_sysconfdir}/udev/rules.d/99-azure-product-uuid.rules %{buildroot}/lib/udev/rules.d/
%else
mkdir -p %{buildroot}/usr/lib/udev/rules.d
install -D -m 0644 %{SOURCE1} %{buildroot}/usr/lib/udev/rules.d/99-azure-timeout.rules
mv %{buildroot}/%{_sysconfdir}/udev/rules.d/99-azure-product-uuid.rules %{buildroot}/usr/lib/udev/rules.d/
%endif
### log file ghost
mkdir -p  %{buildroot}/%{_localstatedir}/log
touch %{buildroot}/%{_localstatedir}/log/waagent.log

%pre
%if 0%{?suse_version} > 1140
    %service_add_pre waagent.service
%endif

%post
%if 0%{?suse_version} > 1140
    %service_add_post waagent.service
%endif

%preun
%if 0%{?suse_version} > 1140
    %service_del_preun waagent.service
%else
    %stop_on_removal waagent
%endif

%postun
%restart_on_update waagent
%if 0%{?suse_version} > 1140
    %service_del_postun waagent.service
%else
    %insserv_cleanup
%endif

%files
%defattr(0644,root,root,0755)
%doc Changelog LICENSE-2.0.txt NOTICE README README.SUSE
%attr(0755,root,root) %{_sbindir}/waagent
%config(noreplace) %{_sysconfdir}/logrotate.d/waagent
%config(noreplace) %{_sysconfdir}/waagent.conf
%ghost %{_localstatedir}/log/waagent.log
%if 0%{?suse_version} > 1140
%{_unitdir}/waagent.service
%else
%attr(0755,root,root) %{_initddir}/waagent
%{_sbindir}/rcwaagent
%endif
%if 0%{?suse_version} < 1230
%config /lib/udev/rules.d/99-azure-timeout.rules
%config /lib/udev/rules.d/99-azure-product-uuid.rules
%else
%config /usr/lib/udev/rules.d/99-azure-timeout.rules
%config /usr/lib/udev/rules.d/99-azure-product-uuid.rules
%endif

%changelog
* Tue Jan 19 2016 rjschwei@suse.com
- Update to version 2.0.17 (bsc#962589)
  + add the support for the rdma driver installing/updating.
    (this in only for SUSE)
- From 2.0.16
  + Handle 410 when reporting health
  + Add timeout to http request
  + Fix multiple issues with extension handling
- From 2.0.15
  + FreeBSD - fix default gateway
  + Oracle - fix distro name detection
  + Redhat - Port "chpasswd" from 2.1
* Mon Oct 19 2015 rjschwei@suse.com
- Fix descriptions for naming of the product
* Thu Jul  2 2015 rjschwei@suse.com
- Update to version 2.0.14 (bnc#936908)
  + Fix rdma config
  + Fix page blob uploading for python 2.6
  + Fix http request error handling
* Fri Jun  5 2015 rjschwei@suse.com
- Update to version 2.0.13 (bnc#933695,bnc#933761)
  + Handle http 410 returned by host
  + Add support for http proxy
  + Add support to execute CustomData after provisioning
  + Add a udev rule for product-uuid to be world readable (bnc#933774)
  + Fix agent path for CoreOS
  + Update service start/stop command for Ubuntu
* Wed Mar 25 2015 rjschwei@suse.com
- Update to version 2.0.12 (bnc#924135,bnc#924137,bnc#919244)
  + Add support for page blob status report
  + Restart the service on upgrade
* Wed Dec 17 2014 rschweikert@suse.com
- Set the config file to noreplace
* Fri Dec 12 2014 rschweikert@suse.com
- Update to version 2.0.11 (bnc#909701)
  + Implementation to support G-Series instances
  + Multiple fixes for openSUSE-13.2+
  + Multiple fixes for FreeBSD
  + Remove waagent-use-wicked-for-13_2.patch, now included in upstream source
* Mon Nov 24 2014 bear454@opensuse.org
- Apply patch to use wicked in openSUSE 13.2
  from PR#57 ( https://github.com/Azure/WALinuxAgent/pull/57 )
  + waagent-use-wicked-for-13_2.patch
* Mon Nov 24 2014 bear454@opensuse.org
- Update to version 2.0.9
  + Change project url
* Fri Sep 26 2014 rschweikert@suse.com
- Update to version 2.0.8
  + Fix for extension timeout handling
* Thu Aug 14 2014 rschweikert@suse.com
- Update to version 2.0.7
  + Add warning for resource disk data loss
  + Multiple fixes for provisioning and extension handler
  + Add support for Gentoo
  + Multiple fixes for extension handler in status report and heartbeat
* Wed May 28 2014 rschweikert@suse.com
- update to version 2.0.5 (bnc#880949)
  + Multiple fixes for FreeBSD provisioning
  + Add support for SLES 12
  + Multiple fixes for extension handler framework
  - New logging support
  - Add state handling for each extension
  - Properly handle non-JSON extensions
  - Several other bugfixes
  + Replace platform.* calls with DistInfo() function
  + Inherit from redhatDistro in centosDistro class
  + Fix hostname configuration for RHEL7-based systems
  + EnvMonitor - Set SCSI I/O timeout for all attached disks
* Mon Apr 14 2014 rschweikert@suse.com
- update to version 2.0.4
  + Fix encoding issue in LogToFile() & LogToCon()
  + Add support for parsing ExtensionsConfiguration from GoalState document
  + Add support for the Fedora distribution
  + Several fixes to FreeBSDDistro class
* Thu Feb 13 2014 rschweikert@suse.com
- include in SLE 12 (FATE #315991)
* Sat Jan 25 2014 rschweikert@suse.com
- update to version 2.0.3
  + Add exception awareness to GetFileContents, SetFileContents, and
    AppendFileContents
  + Fix publishHostname() - leave dhclient.conf alone if it is already
    configured to send the system's current hostname to the DHCP server.
* Tue Jan 14 2014 aosthof@suse.de
- Update to 2.0.2 (bnc#858634)
* Wed Jan  1 2014 rschweikert@suse.com
- update to version 2.0.2
  + remove obsolete patch waAgent_sysvfixes.diff (integrated upstream)
  + Fix UpdateAndPublishHostName() to use correct interface name
  + Specialize file mode of /etc/shadow when clearing the root password
  + Fix publishHostname() to use self.hostname_file_path
  + Remove reference to VM shutdown on "stopped" state. This behavior was an
    artifact from pre-GA IaaS VMs on Windows Azure.
  + Revert to logging non-verbose by default
  + Revert to no swap setup by default (same as 1.x behavior)
* Wed Nov 27 2013 rschweikert@suse.com
- do not own the systemd directories
- put the udev rules into /lib or /usr/lib based on distro
- guard the %%pr and %%post macros, fixes build on SLE
* Wed Nov 27 2013 rschweikert@suse.com
- fix up the systemd macro use to handle install, updated etc properly
* Wed Nov 27 2013 rschweikert@suse.com
- handle differences between systemd unit file location between
  openSUSE 12.2 and later properly
* Wed Nov 27 2013 rschweikert@suse.com
- Build as noarch also for SLE
* Tue Nov 26 2013 aosthof@suse.de
- Version 2.0.1 also fixes bnc#827744
* Thu Nov 21 2013 aosthof@suse.de
- Update to 2.0.1 (bnc#851550)
* Sat Nov  9 2013 rschweikert@suse.com
- update to 2.0.1
  + Add support for CustomData
  + Add exception handling for external consumer scripts
  + Ensure correct unicode encoding for ovf-env.xml
  + Add self.service_cmd for distro compatibility
  + Fix DeleteAccount() with -deprovision+user
  + Save/Restore SELinux state during provision
- add waAgent_sysvfixes.diff
  + these changes missed the 2.0.1 release
* Mon Nov  4 2013 rschweikert@suse.com
- some spec file clean up
* Tue Oct 15 2013 rschweikert@suse.com
- update to 2.0.0
  * Support for wire protocol 2012-11-30
  * Added support for Python3 via 2to3
  * Added support for new Linux distributions and FreeBSD (see README)
  * Source is now importable as a python module
  * Code refactor to ease task of adding/testing new Linux distributions and
    improve code readability
  * Add support for bootstrapping VMM agent for Linux when running in SCVMM
    2012R2 environments (see README)
  * Fix DVD detection for non-en locales
* Sun Aug 11 2013 rschweikert@suse.com
- fix URL and fix dangling ' adressed buils issues on SLE
* Sun Aug 11 2013 rschweikert@suse.com
- Update setup.py, fixes issues with prefix and root cmdline args
* Sat Aug 10 2013 rschweikert@suse.com
- update to 1.3.4-PRE
  * update spec file to take advantage of new setup.py
  * Add support for bootstrapping VMM agent for Linux when running in SCVMM
    2012R2 environments (see README)
  * Add setup.py to assist in package creation
  * Fix DVD detection for non-en locales
  * Improve pyasn1 python module import
  * Improve wire protocol version checking, remove superfluous warning
  * Include support for walking /sys/bus/vmbus/devices for older distributions
  * Include support for creation of sudoers.d for older distributions
  * Remove old references to IsWindows() (used for testing)
  * Fix agent exit if GoalState=None
  * Fix unhandled socket exception (Util.HttpPost/Util._HttpGet)
  * Agent verbose log lines are missing in log when 'verbose' option is used
* Thu Feb 28 2013 mvyskocil@suse.com
- update to 1.3.2 (bnc#805648)
  * Fix name error in _HttpGet/HttpPost exception handlers.
* Mon Feb 25 2013 mvyskocil@suse.com
- update to 1.3.1 (bnc#805648)
  * Merge RPM packaging information.
  * Capture all system command output if an error has occurred.  Normalization
    of shell commands on python subprocess module.
  * Duplicate non-verbose log output to /dev/console.  This to support serial
    logging from boot when console=/dev/ttyS0 is set in the kernel boot options.
  * Merge Ubuntu packaging.
  * Fixed typo in DVD mounting procedure, thanks Ante.
* Mon Feb  4 2013 mvyskocil@suse.com
- fix a default disk format to ext3 (bec6ebca)
* Fri Feb  1 2013 mvyskocil@suse.com
- fix a daemon startup
  * upload new tarball with c7e152178 included
* Thu Jan 31 2013 mvyskocil@suse.com
- drop the hyperv modalias - it does not work for Studio, but all
  Azure appliances are built there
- add README.SUSE explaining the purpose of a package
* Thu Jan 24 2013 mvyskocil@suse.com
- update to 1.3 (bnc#800269)
  * error checking and robustness to DVD mounting operation during
    provisioning
  * Remove redundant check for IP and Port in LoadBalancerProbe
  * Add check to self.computername to detect empty hostname in configuration
- limit installation on packages running under hyperv
- fix few issues from bnc#794736
  * fix encoding and eol-style of README (now utf-8 and unix)
  * /etc/waagent.conf is no longer noreplace
  * init script now start a daemon only once
* Tue Dec 18 2012 mvyskocil@suse.com
- fixes waagent status (bnc#794490)
* Wed Dec 12 2012 mvyskocil@suse.com
- update to 1.2 (fate#314651)
  * a bugfix release
- tarball comes from https://github.com/SUSE/WALinuxAgent/tree/SUSE
  with SUSE patches allows packaging
* Fri Dec  7 2012 aosthof@suse.de
- Changed model in udev rule from "Msft Virtual Disk" to "Virtual
  Disk"
* Fri Dec  7 2012 aosthof@suse.de
- Added %%dir %%{_sysconfdir}/udev to %%files section
- Changed 99-azure-timeout.rules to be a %%config file in %%files
  section due to RPMLint warning
* Fri Dec  7 2012 aosthof@suse.de
- Corrected %%dir path in %%files section
* Fri Dec  7 2012 cthiel@suse.com
- add 99-azure-timeout.rules to increase default timeout for all disks attached
* Sun Nov 25 2012 saschpe@suse.de
- Use actually existing (but randomly chosen) RPM group: System/Daemons
- Use SPDX-style license string (Apache-2.0)
- python-xml is a runtime requirement, not build time
- Require logrotate: for logrotation to actually work
- Install init script
- No need to depend on "python" on SUSE, RPM provides a dependency
  on /usr/bin/python
- Install /etc/waagent.conf
* Sun Nov 25 2012 saschpe@suse.de
- Cleanup spec file:
  + Never disable post-build-checks, fix the issues instead
- Change to github.com:saschpe/WALinuxAgent sources for until fixes
  are merged upstream
* Fri Nov  9 2012 walinuxagent@microsoft.com
- Added README and Changelog
- Updated version to 1.1 for release
* Thu May 17 2012 walinuxagent@microsoft.com
- Initial WALinuxAgent packages.
